@@ -90,13 +90,14 @@ MDNavigationLayout:
                         [
                         ['webhook', lambda x: root.ids.screen_manager.app.connectivity_status(self)],
                         ['access-point', lambda x: root.ids.screen_manager.app.announce_now_action(self)],
+                        ['qrcode', lambda x: root.ids.screen_manager.app.ingest_lxm_action(self)],
                         ['email-sync', lambda x: root.ids.screen_manager.app.lxmf_sync_action(self)],
                         ['account-plus', lambda x: root.ids.screen_manager.app.new_conversation_action(self)],
                         ]
 
                 ScrollView:
                     id: conversations_scrollview
-        
+
 
         MDScreen:
             name: "messages_screen"
@@ -222,7 +223,7 @@ MDNavigationLayout:
 
                     MDBoxLayout:
                         orientation: "vertical"
-                        spacing: "8dp"
+                        spacing: "10dp"
                         size_hint_y: None
                         height: self.minimum_height
                         padding: [dp(28), dp(48), dp(28), dp(16)]
@@ -422,13 +423,13 @@ MDNavigationLayout:
                                 id: connectivity_modem_label
                                 text: "Connect via Radio Modem"
                                 font_style: "H6"
-                                disabled: True
+                                disabled: False
 
                             MDSwitch:
                                 id: connectivity_use_modem
                                 active: False
                                 pos_hint: {"center_y": 0.3}
-                                disabled: True
+                                disabled: False
 
                         MDBoxLayout:
                             id: connectivity_modem_fields
@@ -438,11 +439,16 @@ MDNavigationLayout:
                             padding: [0, 0, 0, dp(32)]
 
                             MDTextField:
-                                id: connectivity_modem_cid
-                                hint_text: "Modem Pairing ID"
+                                id: connectivity_modem_ifac_netname
+                                hint_text: "Optional IFAC network name"
+                                text: ""
+                                font_size: dp(24)
+
+                            MDTextField:
+                                id: connectivity_modem_ifac_passphrase
+                                hint_text: "Optional IFAC passphrase"
                                 text: ""
                                 font_size: dp(24)
-                                # disabled: True
 
 
                         MDBoxLayout:
@@ -455,13 +461,13 @@ MDNavigationLayout:
                                 id: connectivity_serial_label
                                 text: "Connect via Serial Port"
                                 font_style: "H6"
-                                disabled: True
+                                disabled: False
 
                             MDSwitch:
                                 id: connectivity_use_serial
                                 active: False
                                 pos_hint: {"center_y": 0.3}
-                                disabled: True
+                                disabled: False
 
                         MDBoxLayout:
                             id: connectivity_serial_fields
@@ -471,46 +477,50 @@ MDNavigationLayout:
                             padding: [0, 0, 0, dp(32)]
 
                             MDTextField:
-                                id: connectivity_serial_baud
-                                hint_text: "Baud Rate"
+                                id: connectivity_serial_ifac_netname
+                                hint_text: "Optional IFAC network name"
                                 text: ""
                                 font_size: dp(24)
-                                # disabled: True
-
-
-                        MDBoxLayout:
-                            orientation: "horizontal"
-                            padding: [0,0,dp(24),0]
-                            size_hint_y: None
-                            height: dp(24)
-                            
-                            MDLabel:
-                                id: connectivity_bluetooth_label
-                                text: "Connect via Bluetooth"
-                                font_style: "H6"
-                                disabled: True
-
-                            MDSwitch:
-                                id: connectivity_use_bluetooth
-                                active: False
-                                pos_hint: {"center_y": 0.3}
-                                disabled: True
-
-                        MDBoxLayout:
-                            id: connectivity_bluetooth_fields
-                            orientation: "vertical"
-                            size_hint_y: None
-                            height: self.minimum_height
-                            padding: [0, 0, 0, dp(32)]
 
                             MDTextField:
-                                id: connectivity_bluetooth_cid
-                                hint_text: "Bluetooth Pairing ID"
+                                id: connectivity_serial_ifac_passphrase
+                                hint_text: "Optional IFAC passphrase"
                                 text: ""
                                 font_size: dp(24)
-                                # disabled: True
 
 
+                        # MDBoxLayout:
+                        #     orientation: "horizontal"
+                        #     padding: [0,0,dp(24),0]
+                        #     size_hint_y: None
+                        #     height: dp(24)
+                            
+                        #     MDLabel:
+                        #         id: connectivity_bluetooth_label
+                        #         text: "Connect via Bluetooth"
+                        #         font_style: "H6"
+                        #         disabled: True
+
+                        #     MDSwitch:
+                        #         id: connectivity_use_bluetooth
+                        #         active: False
+                        #         pos_hint: {"center_y": 0.3}
+                        #         disabled: True
+
+                        # MDBoxLayout:
+                        #     id: connectivity_bluetooth_fields
+                        #     orientation: "vertical"
+                        #     size_hint_y: None
+                        #     height: self.minimum_height
+                        #     padding: [0, 0, 0, dp(32)]
+
+                        #     MDTextField:
+                        #         id: connectivity_bluetooth_cid
+                        #         hint_text: "Bluetooth Pairing ID"
+                        #         text: ""
+                        #         font_size: dp(24)
+                        #         # disabled: True
+
                         MDBoxLayout:
                             orientation: "horizontal"
                             padding: [0,0,dp(24),0]
@@ -521,13 +531,99 @@ MDNavigationLayout:
                                 id: connectivity_transport_label
                                 text: "Enable Reticulum Transport"
                                 font_style: "H6"
-                                disabled: True
+                                # disabled: True
 
                             MDSwitch:
                                 id: connectivity_enable_transport
                                 active: False
                                 pos_hint: {"center_y": 0.3}
-                                disabled: True
+                                # disabled: True
+
+                        MDLabel:
+                            id: connectivity_transport_info
+                            markup: True
+                            text: "Enabling Reticulum Transport will allow this device to route traffic between all enabled interfaces.\\n\\nFor general usage, this option should not be enabled, but it can be useful in situations where you want to share connectivity from one device to many others. An example of this could be sharing connectivity from a radio interface to other people on your local WiFi network.\\n\\nWhen enabled, you will be able to configure the interface mode for all interfaces configured on this device. For more information on this topic, refer to the Reticulum Manual."
+                            size_hint_y: None
+                            text_size: self.width, None
+                            height: self.texture_size[1]
+
+                        MDBoxLayout:
+                            id: connectivity_transport_fields
+                            orientation: "vertical"
+                            size_hint_y: None
+                            height: self.minimum_height
+                            padding: [0, 0, 0, dp(32)]
+
+                            # MDLabel:
+                            #     id: connectivity_modes_info
+                            #     markup: True
+                            #     text: "With Transport enabled, you can configure the interface modes for any enabled interfaces. Changing interface modes affects how Reticulum processes traffic and announces. For more information, refer to the Reticulum Manual."
+                            #     size_hint_y: None
+                            #     text_size: self.width, None
+                            #     height: self.texture_size[1]
+
+                            MDBoxLayout:
+                                orientation: "horizontal"
+                                spacing: "24dp"
+                                size_hint_y: None
+                                height: self.minimum_height
+                                padding: [dp(0), dp(12), dp(0), dp(12)]
+
+                                MDTextField:
+                                    id: connectivity_local_ifmode
+                                    hint_text: "Local Interface Mode"
+                                    text: ""
+                                    font_size: dp(24)
+
+                                MDTextField:
+                                    id: connectivity_tcp_ifmode
+                                    hint_text: "TCP Interface Mode"
+                                    text: ""
+                                    font_size: dp(24)
+
+                            MDBoxLayout:
+                                orientation: "horizontal"
+                                spacing: "24dp"
+                                size_hint_y: None
+                                height: self.minimum_height
+                                padding: [dp(0), dp(12), dp(0), dp(12)]
+
+                                MDTextField:
+                                    id: connectivity_i2p_ifmode
+                                    hint_text: "I2P Mode"
+                                    text: ""
+                                    font_size: dp(24)
+
+                                MDTextField:
+                                    id: connectivity_rnode_ifmode
+                                    hint_text: "RNode Mode"
+                                    text: ""
+                                    font_size: dp(24)
+
+                            MDBoxLayout:
+                                orientation: "horizontal"
+                                spacing: "24dp"
+                                size_hint_y: None
+                                height: self.minimum_height
+                                padding: [dp(0), dp(12), dp(0), dp(12)]
+
+                                MDTextField:
+                                    id: connectivity_modem_ifmode
+                                    hint_text: "Modem Mode"
+                                    text: ""
+                                    font_size: dp(24)
+
+                                MDTextField:
+                                    id: connectivity_serial_ifmode
+                                    hint_text: "Serial Mode"
+                                    text: ""
+                                    font_size: dp(24)
+
+                            # MDTextField:
+                            #     id: connectivity_bluetooth_ifmode
+                            #     hint_text: "Bluetooth Mode"
+                            #     text: ""
+                            #     font_size: dp(24)
 
         
         MDScreen:
@@ -653,6 +749,7 @@ MDNavigationLayout:
                         orientation: "vertical"
                         size_hint_y: None
                         height: self.minimum_height
+                        spacing: dp(35)
                         padding: [dp(35), dp(32), dp(35), dp(16)]
 
                         MDLabel:
@@ -662,7 +759,23 @@ MDNavigationLayout:
                             size_hint_y: None
                             text_size: self.width, None
                             height: self.texture_size[1]
-        
+
+                        MDBoxLayout:
+                            orientation: "vertical"
+                            size_hint_y: None
+                            size_hint_x: None
+                            height: dp(256)
+                            width: dp(256)
+                            spacing: dp(0)
+                            padding: [dp(0), dp(0), dp(0), dp(0)]
+                            pos_hint: {"center_x": .5, "center_y": .5}
+
+                            MDIcon:
+                                pos_hint: {"center_x": .5, "center_y": .5}
+                                id: information_logo
+                                font_size: "256dp"
+                                width: dp(256)
+                                height: dp(256)
 
         MDScreen:
             name: "map_screen"
@@ -682,7 +795,7 @@ MDNavigationLayout:
                         ]
 
                 ScrollView:
-                    id:information_scrollview
+                    id:map_scrollview
 
                     MDBoxLayout:
                         orientation: "vertical"
@@ -879,14 +992,6 @@ MDNavigationLayout:
                                 max_text_length: 128
                                 font_size: dp(24)
 
-                            MDTextField:
-                                id: settings_lxmf_address
-                                hint_text: "Your LXMF Address"
-                                text: ""
-                                disabled: False
-                                max_text_length: 32
-                                font_size: dp(24)
-
                             MDTextField:
                                 id: settings_propagation_node_address
                                 hint_text: "LXMF Propagation Node"
@@ -903,6 +1008,38 @@ MDNavigationLayout:
                                 max_text_length: 32
                                 font_size: dp(24)
 
+                            MDTextField:
+                                id: settings_print_command
+                                hint_text: "Print Command"
+                                disabled: False
+                                text: ""
+                                max_text_length: 32
+                                font_size: dp(24)
+
+                            MDLabel:
+                                text: ""
+                                font_style: "H6"
+
+                            MDLabel:
+                                text: "Address & Identity"
+                                font_style: "H6"
+
+                            MDTextField:
+                                id: settings_lxmf_address
+                                hint_text: "Your LXMF Address"
+                                text: ""
+                                disabled: False
+                                max_text_length: 32
+                                font_size: dp(24)
+
+                            MDTextField:
+                                id: settings_identity_hash
+                                hint_text: "Your Identity Hash"
+                                text: ""
+                                disabled: False
+                                max_text_length: 32
+                                font_size: dp(24)
+
 
                         MDBoxLayout:
                             orientation: "vertical"
@@ -1117,8 +1254,8 @@ MDNavigationLayout:
                                 icon_size: dp(24)
                                 font_size: dp(16)
                                 size_hint: [1.0, None]
-                                on_release: root.ids.screen_manager.app.hardware_mode_action(self)
-                                disabled: True
+                                on_release: root.ids.screen_manager.app.hardware_modem_action(self)
+                                disabled: False
 
                             MDRectangleFlatIconButton:
                                 id: hardware_serial_button
@@ -1129,7 +1266,7 @@ MDNavigationLayout:
                                 font_size: dp(16)
                                 size_hint: [1.0, None]
                                 on_release: root.ids.screen_manager.app.hardware_serial_action(self)
-                                disabled: True
+                                disabled: False
 
         MDScreen:
             name: "hardware_rnode_screen"
@@ -1165,7 +1302,7 @@ MDNavigationLayout:
                         MDLabel:
                             id: hardware_rnode_info
                             markup: True
-                            text: "To communicate using an RNode, you will need to specify the following parameters. For two or more RNodes to be able to communicate, all parameters must match, except for the [i]Coding Rate[/i] parameter, which can vary between devices.\\n"
+                            text: "To communicate using an RNode, you will need to specify the following parameters. For two or more RNodes to be able to communicate, all parameters must match, except for the [i]Coding Rate[/i] and [i]TX Power[/i] parameter, which can vary between devices.\\n"
                             size_hint_y: None
                             text_size: self.width, None
                             height: self.texture_size[1]
@@ -1275,6 +1412,328 @@ MDNavigationLayout:
                                 text: ""
                                 font_size: dp(24)
 
+                        MDBoxLayout:
+                            orientation: "horizontal"
+                            size_hint_y: None
+                            padding: [0,0,dp(24),dp(0)]
+                            height: dp(48)
+                            
+                            MDLabel:
+                                text: "Connect using Bluetooth"
+                                font_style: "H6"
+
+                            MDSwitch:
+                                id: hardware_rnode_bluetooth
+                                pos_hint: {"center_y": 0.3}
+                                active: False
+
+                        MDLabel:
+                            id: hardware_rnode_info
+                            markup: True
+                            text: "If you enable connection via Bluetooth, Sideband will attempt to connect to any available and paired RNodes over Bluetooth.\\n\\nYou must first pair the RNode with your device for this to work. If your RNode does not have a physical pairing button, you can enable Bluetooth and put it into pairing mode by first connecting it via a USB cable, and using the buttons below. When plugging in the RNode over USB, you must grant Sideband permission to the USB device for this to work.\\n\\nYou can also change Bluetooth settings using the \\"rnodeconf\\" utility from a computer.\\n\\nBy default, Sideband will connect to the first available RNode that is paired. If you want to always use a specific RNode, you can enter its name in the Preferred RNode Device Name field below, for example \\"RNode A8EB\\".\\n"
+                            size_hint_y: None
+                            text_size: self.width, None
+                            height: self.texture_size[1]
+
+                        MDBoxLayout:
+                            orientation: "vertical"
+                            spacing: "24dp"
+                            size_hint_y: None
+                            height: self.minimum_height
+                            # padding: [dp(0), dp(0), dp(0), dp(35)]
+
+                            MDRectangleFlatIconButton:
+                                id: hardware_rnode_bt_on_button
+                                icon: "bluetooth"
+                                text: "Enable Bluetooth"
+                                padding: [dp(0), dp(14), dp(0), dp(14)]
+                                icon_size: dp(24)
+                                font_size: dp(16)
+                                size_hint: [1.0, None]
+                                on_release: root.ids.screen_manager.app.hardware_rnode_bt_on_action(self)
+
+                            MDRectangleFlatIconButton:
+                                id: hardware_rnode_bt_off_button
+                                icon: "bluetooth-off"
+                                text: "Disable Bluetooth"
+                                padding: [dp(0), dp(14), dp(0), dp(14)]
+                                icon_size: dp(24)
+                                font_size: dp(16)
+                                size_hint: [1.0, None]
+                                on_release: root.ids.screen_manager.app.hardware_rnode_bt_off_action(self)
+                                disabled: False
+
+                            MDRectangleFlatIconButton:
+                                id: hardware_rnode_bt_pair_button
+                                icon: "link-variant"
+                                text: "Start Pairing Mode"
+                                padding: [dp(0), dp(14), dp(0), dp(14)]
+                                icon_size: dp(24)
+                                font_size: dp(16)
+                                size_hint: [1.0, None]
+                                on_release: root.ids.screen_manager.app.hardware_rnode_bt_pair_action(self)
+                                disabled: False
+
+                            MDTextField:
+                                id: hardware_rnode_bt_device
+                                hint_text: "Preferred RNode Device Name"
+                                text: ""
+                                font_size: dp(24)
+
+        MDScreen:
+            name: "hardware_modem_screen"
+            
+            BoxLayout:
+                orientation: "vertical"
+
+                MDTopAppBar:
+                    title: "Radio Modem"
+                    anchor_title: "left"
+                    elevation: 2
+                    left_action_items:
+                        [['menu', lambda x: nav_drawer.set_state("open")]]
+                    right_action_items:
+                        [
+                        ['close', lambda x: root.ids.screen_manager.app.close_sub_hardware_action(self)],
+                        ]
+
+                ScrollView:
+                    id: hardware_modem_scrollview
+
+                    MDBoxLayout:
+                        orientation: "vertical"
+                        spacing: "8dp"
+                        size_hint_y: None
+                        height: self.minimum_height
+                        padding: [dp(28), dp(48), dp(28), dp(16)]
+
+                        MDLabel:
+                            text: "Modem Hardware Parameters\\n"
+                            font_style: "H6"
+
+                        MDLabel:
+                            id: hardware_modem_info
+                            markup: True
+                            text: "To communicate using a Radio Modem, you will need to specify the following parameters. Serial port parameters must be set to match those of the modem. CSMA parameters can be left at their default values in most cases.\\n"
+                            size_hint_y: None
+                            text_size: self.width, None
+                            height: self.texture_size[1]
+
+                        MDLabel:
+                            text: "Port Options"
+                            font_style: "H6"
+
+                        MDBoxLayout:
+                            orientation: "horizontal"
+                            spacing: "24dp"
+                            size_hint_y: None
+                            height: self.minimum_height
+                            # padding: [dp(0), dp(0), dp(0), dp(35)]
+
+                            MDTextField:
+                                id: hardware_modem_baudrate
+                                hint_text: "Baud Rate"
+                                text: ""
+                                font_size: dp(24)
+
+                        MDBoxLayout:
+                            orientation: "horizontal"
+                            spacing: "24dp"
+                            size_hint_y: None
+                            height: self.minimum_height
+                            padding: [dp(0), dp(0), dp(0), dp(24)]
+
+                            MDTextField:
+                                id: hardware_modem_databits
+                                hint_text: "Data Bits"
+                                text: ""
+                                font_size: dp(24)
+
+                            MDTextField:
+                                id: hardware_modem_parity
+                                hint_text: "Parity"
+                                text: ""
+                                font_size: dp(24)
+
+                            MDTextField:
+                                id: hardware_modem_stopbits
+                                hint_text: "Stop Bits"
+                                text: ""
+                                font_size: dp(24)
+
+                        MDLabel:
+                            text: "CSMA Parameters"
+                            font_style: "H6"
+
+                        MDBoxLayout:
+                            orientation: "horizontal"
+                            spacing: "24dp"
+                            size_hint_y: None
+                            height: self.minimum_height
+                            padding: [dp(0), dp(0), dp(0), dp(0)]
+
+                            MDTextField:
+                                id: hardware_modem_preamble
+                                hint_text: "Preamble (ms)"
+                                text: ""
+                                font_size: dp(24)
+
+                            MDTextField:
+                                id: hardware_modem_tail
+                                hint_text: "TX Tail (ms)"
+                                text: ""
+                                font_size: dp(24)
+
+                        MDBoxLayout:
+                            orientation: "horizontal"
+                            spacing: "24dp"
+                            size_hint_y: None
+                            height: self.minimum_height
+                            padding: [dp(0), dp(0), dp(0), dp(24)]
+
+                            MDTextField:
+                                id: hardware_modem_persistence
+                                hint_text: "Persistence (1-255)"
+                                text: ""
+                                font_size: dp(24)
+
+                            MDTextField:
+                                id: hardware_modem_slottime
+                                hint_text: "Slot Time (ms)"
+                                text: ""
+                                font_size: dp(24)
+
+                        MDLabel:
+                            text: "Optional Settings"
+                            font_style: "H6"
+
+                        MDBoxLayout:
+                            orientation: "horizontal"
+                            spacing: "24dp"
+                            size_hint_y: None
+                            height: self.minimum_height
+                            # padding: [dp(0), dp(0), dp(0), dp(35)]
+
+                            MDTextField:
+                                id: hardware_modem_beaconinterval
+                                hint_text: "Beacon Interval (seconds)"
+                                text: ""
+                                font_size: dp(24)
+
+                            MDTextField:
+                                id: hardware_modem_beacondata
+                                hint_text: "Beacon Data"
+                                text: ""
+                                font_size: dp(24)
+
+        MDScreen:
+            name: "hardware_serial_screen"
+            
+            BoxLayout:
+                orientation: "vertical"
+
+                MDTopAppBar:
+                    title: "Serial Port"
+                    anchor_title: "left"
+                    elevation: 2
+                    left_action_items:
+                        [['menu', lambda x: nav_drawer.set_state("open")]]
+                    right_action_items:
+                        [
+                        ['close', lambda x: root.ids.screen_manager.app.close_sub_hardware_action(self)],
+                        ]
+
+                ScrollView:
+                    id: hardware_serial_scrollview
+
+                    MDBoxLayout:
+                        orientation: "vertical"
+                        spacing: "8dp"
+                        size_hint_y: None
+                        height: self.minimum_height
+                        padding: [dp(28), dp(48), dp(28), dp(16)]
+
+                        MDLabel:
+                            text: "Serial Hardware Parameters\\n"
+                            font_style: "H6"
+
+                        MDLabel:
+                            id: hardware_serial_info
+                            markup: True
+                            text: "To communicate using a serial port, you will need to specify the following parameters. If communicating directly to another Reticulum instance over serial, the parameters must match the other device.\\n\\nIf you are using a serial-connected device to pass on data to other Reticulum instances, it should be configured to pass data transparently to the desired endpoints.\\n"
+                            size_hint_y: None
+                            text_size: self.width, None
+                            height: self.texture_size[1]
+
+                        # MDBoxLayout:
+                        #     orientation: "horizontal"
+                        #     spacing: "24dp"
+                        #     size_hint_y: None
+                        #     height: self.minimum_height
+                        #     padding: [dp(0), dp(0), dp(0), dp(35)]
+
+                        #     MDRectangleFlatIconButton:
+                        #         id: serial_mote_export
+                        #         icon: "upload"
+                        #         text: "Export"
+                        #         padding: [dp(0), dp(14), dp(0), dp(14)]
+                        #         icon_size: dp(24)
+                        #         font_size: dp(16)
+                        #         size_hint: [1.0, None]
+                        #         on_release: root.ids.screen_manager.app.hardware_serial_export(self)
+
+                        #     MDRectangleFlatIconButton:
+                        #         id: serial_mote_import
+                        #         icon: "download"
+                        #         text: "Import"
+                        #         padding: [dp(0), dp(14), dp(0), dp(14)]
+                        #         icon_size: dp(24)
+                        #         font_size: dp(16)
+                        #         size_hint: [1.0, None]
+                        #         on_release: root.ids.screen_manager.app.hardware_serial_import(self)
+
+                        MDLabel:
+                            text: "Port Options"
+                            font_style: "H6"
+
+                        MDBoxLayout:
+                            orientation: "horizontal"
+                            spacing: "24dp"
+                            size_hint_y: None
+                            height: self.minimum_height
+                            # padding: [dp(0), dp(0), dp(0), dp(35)]
+
+                            MDTextField:
+                                id: hardware_serial_baudrate
+                                hint_text: "Baud Rate"
+                                text: ""
+                                font_size: dp(24)
+
+                        MDBoxLayout:
+                            orientation: "horizontal"
+                            spacing: "24dp"
+                            size_hint_y: None
+                            height: self.minimum_height
+                            padding: [dp(0), dp(0), dp(0), dp(24)]
+
+                            MDTextField:
+                                id: hardware_serial_databits
+                                hint_text: "Data Bits"
+                                text: ""
+                                font_size: dp(24)
+
+                            MDTextField:
+                                id: hardware_serial_parity
+                                hint_text: "Parity"
+                                text: ""
+                                font_size: dp(24)
+
+                            MDTextField:
+                                id: hardware_serial_stopbits
+                                hint_text: "Stop Bits"
+                                text: ""
+                                font_size: dp(24)
+
 
     MDNavigationDrawer:
         id: nav_drawer
@@ -1290,6 +1749,7 @@ MDNavigationLayout:
                         OneLineIconListItem:
                             text: "Conversations"
                             on_release: root.ids.screen_manager.app.conversations_action(self)
+                            # _no_ripple_effect: True
                         
                             IconLeftWidget:
                                 icon: "email"
@@ -1326,7 +1786,6 @@ MDNavigationLayout:
                         OneLineIconListItem:
                             text: "Preferences"
                             on_release: root.ids.screen_manager.app.settings_action(self)
-                            _no_ripple_effect: True
                         
                             IconLeftWidget:
                                 icon: "cog"
@@ -1336,7 +1795,6 @@ MDNavigationLayout:
                         OneLineIconListItem:
                             text: "Connectivity"
                             on_release: root.ids.screen_manager.app.connectivity_action(self)
-                            _no_ripple_effect: True
                         
                             IconLeftWidget:
                                 icon: "wifi"
@@ -1346,7 +1804,6 @@ MDNavigationLayout:
                         OneLineIconListItem:
                             text: "Hardware"
                             on_release: root.ids.screen_manager.app.hardware_action(self)
-                            _no_ripple_effect: True
                         
                             IconLeftWidget:
                                 icon: "router-wireless"
@@ -1356,7 +1813,6 @@ MDNavigationLayout:
                         OneLineIconListItem:
                             text: "Encryption Keys"
                             on_release: root.ids.screen_manager.app.keys_action(self)
-                            _no_ripple_effect: True
                         
                             IconLeftWidget:
                                 icon: "key-chain"
@@ -1366,7 +1822,6 @@ MDNavigationLayout:
                         OneLineIconListItem:
                             text: "Guide"
                             on_release: root.ids.screen_manager.app.guide_action(self)
-                            _no_ripple_effect: True
                         
                             IconLeftWidget:
                                 icon: "book-open"
@@ -1377,7 +1832,6 @@ MDNavigationLayout:
                             id: app_version_info
                             text: ""
                             on_release: root.ids.screen_manager.app.information_action(self)
-                            _no_ripple_effect: True
                         
                             IconLeftWidget:
                                 icon: "information"
@@ -1387,7 +1841,6 @@ MDNavigationLayout:
                         OneLineIconListItem:
                             text: "Shutdown"
                             on_release: root.ids.screen_manager.app.quit_action(self)
-                            _no_ripple_effect: True
                         
                             IconLeftWidget:
                                 icon: "power"
@@ -1509,7 +1962,7 @@ MDNavigationLayout:
     MDBoxLayout:
         orientation: "horizontal"
         size_hint_y: None
-        padding: [0,0,dp(8),0]
+        padding: [0,0,dp(8),dp(24)]
         height: dp(48)
         MDLabel:
             id: "trusted_switch_label"
